==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/igr-annotation-layer.js <==
import { __extends } from "tslib";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.up;
        },
        set: function (v) {
            this.i.up = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.uq;
        },
        set: function (v) {
            this.i.uq = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.w0);
        },
        set: function (v) {
            this.i.w0 = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.uk;
        },
        set: function (v) {
            this.i.uk = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.eg;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "appearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t6;
        },
        set: function (v) {
            this.i.t6 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t3;
        },
        set: function (v) {
            this.i.t3 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.u3;
        },
        set: function (v) {
            this.i.u3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.us;
        },
        set: function (v) {
            this.i.us = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.ud;
        },
        set: function (v) {
            this.i.ud = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t4;
        },
        set: function (v) {
            this.i.t4 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.ue;
        },
        set: function (v) {
            this.i.ue = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.t5;
        },
        set: function (v) {
            this.i.t5 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.u2;
        },
        set: function (v) {
            this.i.u2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.ur;
        },
        set: function (v) {
            this.i.ur = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.u4;
        },
        set: function (v) {
            this.i.u4 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.ut;
        },
        set: function (v) {
            this.i.ut = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.wx);
        },
        set: function (v) {
            this.i.wx = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.wr);
        },
        set: function (v) {
            this.i.wr = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.wy);
        },
        set: function (v) {
            this.i.wy = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.ws);
        },
        set: function (v) {
            this.i.ws = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.eu;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.d7;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.uo;
        },
        set: function (v) {
            this.i.uo = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };

==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/igr-annotation-layer.js <==
import { __extends } from "tslib";
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.xc;
        },
        set: function (v) {
            this.i.xc = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.xd;
        },
        set: function (v) {
            this.i.xd = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.zn);
        },
        set: function (v) {
            this.i.zn = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.w7;
        },
        set: function (v) {
            this.i.w7 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.ez;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "appearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wt;
        },
        set: function (v) {
            this.i.wt = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wq;
        },
        set: function (v) {
            this.i.wq = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xq;
        },
        set: function (v) {
            this.i.xq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xf;
        },
        set: function (v) {
            this.i.xf = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w0;
        },
        set: function (v) {
            this.i.w0 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.wr;
        },
        set: function (v) {
            this.i.wr = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.w1;
        },
        set: function (v) {
            this.i.w1 = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalAppearanceMode", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return this.i.ws;
        },
        set: function (v) {
            this.i.ws = ensureEnum(AnnotationAppearanceMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xp;
        },
        set: function (v) {
            this.i.xp = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xe;
        },
        set: function (v) {
            this.i.xe = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xr;
        },
        set: function (v) {
            this.i.xr = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalShiftAmount", {
        /**
         * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
        */
        get: function () {
            return this.i.xg;
        },
        set: function (v) {
            this.i.xg = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "horizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zk);
        },
        set: function (v) {
            this.i.zk = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualHorizontalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.ze);
        },
        set: function (v) {
            this.i.ze = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "verticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zl);
        },
        set: function (v) {
            this.i.zl = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "actualVerticalDashArray", {
        /**
         * Gets or sets the mode used for shifting the annotation layer color based on the target series.
        */
        get: function () {
            return fromDoubleCollection(this.i.zf);
        },
        set: function (v) {
            this.i.zf = toDoubleCollection(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.fe;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.eq;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.xb;
        },
        set: function (v) {
            this.i.xb = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };
